@@ -245,6 +245,7 @@ class Gantt:
 
             # Add new dependencies as encountered
             row_dependency_list = row['dependencies'].split('&&') if row['dependencies'] != '' else []
+            row_dependency_list = [int(id) for id in row_dependency_list]
 
             # sub activities
             # TODO: Add validation around the structure of sub activities
@@ -278,7 +279,7 @@ class Gantt:
 
             # add
             clean_tasks_data.append({
-                'id': row['id'],
+                'id': int(row['id']),
                 'activity_type': activity_type,
                 'activity': row['activity'],
                 'state': state,
@@ -368,6 +369,10 @@ class Gantt:
             for t in proj.activities:
                 yield t
 
+    @property
+    def has_been_scheduled(self):
+        return not any(self.activities_not_scheduled)
+
     def calculate_schedule(self,
                            start_date,
                            max_resources_per_project: Dict[str, Dict[str, int]] = None,
@@ -410,6 +415,7 @@ class Gantt:
         shouldnt_be_left = self.activities_not_scheduled
         if any(shouldnt_be_left):
             raise IncompleteOperationError(f"The following {len(shouldnt_be_left)} activities were not scheduled: [{shouldnt_be_left}]")
+
     @property
     def flattened_tasks_across_projects(self):
         #create a list of activities sorted on their relative priority
@@ -451,6 +457,9 @@ class Gantt:
         activities_with_target_date.sort(key=lambda x: x.target_completion_date)
 
         # Schedule items in target_date order. Will also appropriately schedule pre-decessors
+        if max_resources_per_project is None:
+            max_resources_per_project = {}
+
         for item in activities_with_target_date:
             item.schedule(start_date, max_resources_per_project.get(item.project.name, None))
 
@@ -479,6 +488,9 @@ class Gantt:
         needs_scheduled.sort(key=lambda x: x.extrapolated_priority * project_priority.get(x.project.name, 10))
 
         # Schedule remaining
+        if max_resources_per_project is None:
+            max_resources_per_project = {}
+
         for item in needs_scheduled:
             item.schedule(start_date, max_resources_per_project.get(item.project.name, None))
 
@@ -502,6 +514,9 @@ class Gantt:
         needs_scheduled.sort(key=lambda x: (defined_schedule_sequence.get(x, None) is None, defined_schedule_sequence.get(x, None)))
 
         # Schedule items in defined_schedule order. Will also appropriately schedule pre-decessors
+        if max_resources_per_project is None:
+            max_resources_per_project = {}
+
         for item in needs_scheduled:
             # Once hit None's, done scheduling according to definition
             if defined_schedule_sequence.get(item, None) is None:
